@@ -83,7 +83,7 @@ MODIStsp_process_bands <- function(out_folder_mod, modislist,
   gdalinfo_raw  <- if (length(gdalinfo_hdf_1stlayer) > 0) {
     # if more than a band is present, take gdalinfo from the first
     # band
-    gdalUtils::gdalinfo(gdalinfo_hdf_1stlayer)
+    gdalUtils::gdalinfo(file.path(out_folder_mod, modislist[1]), sd = 1)
   } else {
     # otherwise, take from the HDF directly
     gdalinfo_hdf_raw
@@ -328,6 +328,26 @@ MODIStsp_process_bands <- function(out_folder_mod, modislist,
     outrep_file
   }
 
+  # workaround on gdal >= 2.3
+  gdalutils_ver <- getOption("gdalUtils_gdalPath")[[1]]$version[[1]]
+  gdalutils_ver <- as.numeric(substring(gdalutils_ver, 1,3))
+
+  # Fix needed to avoid that scale and offset are automatically "applied"
+  # when working with GDAL > 2.3.x
+  if (gdalutils_ver >= 2.3 & tools::file_ext(outfile_vrt) == "vrt") {
+    vrt_in      <- readLines(outfile_vrt)
+    scale_line <- grep("Scale", vrt_in)
+    if (length(scale_line) != 0) {
+      vrt_in[[scale_line]] <- "<Scale>1</Scale>"
+    }
+
+    offset_line <- grep("Offset", vrt_in)
+    if (length(offset_line) != 0) {
+      vrt_in[[offset_line]] <- "<Offset>0</Offset>"
+    }
+
+    writeLines(vrt_in, outfile_vrt)
+  }
   # Launch the spatial processing -
   # operations to be done depend on whether resize and/or
   # reprojection and/or resampling are necessary. Operations
@@ -547,7 +567,6 @@ MODIStsp_process_bands <- function(out_folder_mod, modislist,
     rm(outrep, outrep_0)
   }
 
-
   # If output format is ENVI, add data ignore value to the
   # header file
   if (out_format == "ENVI") {
